@@ -11,3 +11,9 @@ def sanitize_path(path: Path) -> Path:
     if not isinstance(path, Path):
         raise ValueError
     return sanitize_filepath(path, platform='auto')
+
+
+def sanitize_label(label: str, subs: str = "□") -> str:
+    if not label.isprintable():
+        return "".join(char.isprintable() and char or subs for char in label)
+    return label
